@@ -1,39 +1,3 @@
-setClass("pixmap",
-         representation(size="integer",
-                        cellres="numeric",
-                        bbox="numeric",
-                        bbcent="logical"),
-         prototype(size=integer(2),
-                   cellres=numeric(2),
-                   bbox=numeric(4)))
-
-setClass("pixmapChannels",
-         representation(channels="character"),
-         contains="pixmap")
-
-setClass("pixmapGrey",
-         representation(grey="matrix"),
-         contains="pixmapChannels",
-         prototype=prototype(new("pixmap"), channels="grey"))
-
-
-setClass("pixmapIndexed",
-         representation(index="matrix",
-                        col="character"),
-         contains="pixmap",
-         prototype=prototype(new("pixmap")))
-
-setClass("pixmapRGB",
-         representation(red="matrix",
-                        green="matrix",
-                        blue="matrix"),
-         contains="pixmapChannels",
-         prototype=prototype(new("pixmap"),
-                             channels=c("red", "green", "blue")))
-
-
-
-###**********************************************************
 
 setMethod("show", "pixmap",
 function(object){
@@ -69,7 +33,7 @@ pixmap <- function(data=NULL, nrow=dim(data)[1],
                    ncol=dim(data)[2],
                    bbox=NULL, bbcent=FALSE, cellres=NULL)
 {
-    cellres <- rep(cellres, length=2)
+    if(!is.null(cellres)) cellres <- rep(cellres, length.out = 2)
     if(is.null(bbox)){
         if(is.null(cellres))
             cellres <- c(1,1)
@@ -168,7 +132,7 @@ pixmapIndexed = function(data, col=NULL, ...)
         else {
             if(length(col) < datamax){
                 warning("number of of colors smaller than number of data values, recycling\n")
-                col <- rep(col, length=datamax)
+                col <- rep(col, length.out = datamax)
             }
         }
     }
